@@ -1,32 +1,20 @@
 /*
- *   Copyright (C) 2000 Matthias Elter <elter@kde.org>
- *   Copyright (C) 2001-2002 Raffaele Sandrini <sandrini@kde.org)
- *   Copyright (C) 2008 Montel Laurent <montel@kde.org)
+ *   SPDX-FileCopyrightText: 2000 Matthias Elter <elter@kde.org>
+ *   SPDX-FileCopyrightText: 2001-2002 Raffaele Sandrini <sandrini@kde.org>
+ *   SPDX-FileCopyrightText: 2008 Montel Laurent <montel@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
-#include <KLocalizedString>
 #include <KAboutData>
-#include <kdbusservice.h>
+#include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
+#include <kdbusservice.h>
 
+#include "kmenuedit.h"
 #include <QApplication>
 #include <QCommandLineParser>
-#include "kmenuedit.h"
 
 static const char description[] = I18N_NOOP("KDE menu editor");
 
@@ -56,8 +44,11 @@ int main(int argc, char **argv)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     KLocalizedString::setApplicationDomain("kmenuedit");
 
-    KAboutData aboutData(QStringLiteral("kmenuedit"), i18n("KDE Menu Editor"),
-                         QStringLiteral(PROJECT_VERSION), i18n(description), KAboutLicense::GPL,
+    KAboutData aboutData(QStringLiteral("kmenuedit"),
+                         i18n("KDE Menu Editor"),
+                         QStringLiteral(PROJECT_VERSION),
+                         i18n(description),
+                         KAboutLicense::GPL,
                          i18n("(C) 2000-2003, Waldo Bastian, Raffaele Sandrini, Matthias Elter"));
     aboutData.addAuthor(i18n("Waldo Bastian"), i18n("Maintainer"), QStringLiteral("bastian@kde.org"));
     aboutData.addAuthor(i18n("Raffaele Sandrini"), i18n("Previous Maintainer"), QStringLiteral("sandrini@kde.org"));
@@ -69,12 +60,8 @@ int main(int argc, char **argv)
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("KDE Menu Editor"));
-    parser.addPositionalArgument(QStringLiteral("menu"),
-                                 i18n("Sub menu to pre-select"),
-                                 QStringLiteral("[menu]"));
-    parser.addPositionalArgument(QStringLiteral("menu-id"),
-                                 i18n("Menu entry to pre-select"),
-                                 QStringLiteral("[menu-id]"));
+    parser.addPositionalArgument(QStringLiteral("menu"), i18n("Sub menu to pre-select"), QStringLiteral("[menu]"));
+    parser.addPositionalArgument(QStringLiteral("menu-id"), i18n("Menu entry to pre-select"), QStringLiteral("[menu-id]"));
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
